#
# spec file for package python-qtcharts-qt5
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define oldpython python
%define mname qtcharts-qt5
%{?sle15_python_module_pythons}
Name:           python-%{mname}
Version:        5.15.6
Release:        5.1
Summary:        Python bindings for the Qt5 Charts library
License:        GPL-3.0-only
Group:          Development/Libraries/Python
URL:            https://www.riverbankcomputing.com/software/pyqtchart/intro
Source:         https://files.pythonhosted.org/packages/source/P/PyQtChart/PyQtChart-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pyqt-builder >= 1.9}
BuildRequires:  %{python_module qt5-devel >= 5.15.4}
BuildRequires:  %{python_module sip-devel >= 5.3}
BuildRequires:  fdupes
BuildRequires:  python-pyqt-rpm-macros
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(Qt5Charts)
Requires:       python-qt5 >= %(rpm -q --whatprovides python-qt5 --qf "%%{version}")
Requires:       python-qt5-sip
# PyPI name is without the s at the end
Provides:       python-PyQtChart = %{version}-%{release}
%python_subpackages

%description
PyQtChart is a set of Python bindings for the Qt5 Charts library.

%package        api
Summary:        Eric API files for %{name}
Group:          Development/Tools/IDE
Supplements:    packageand(eric:python-%{mname})

%description    api
This package provides Qt5 Charts library API files for the Eric IDE.

%package sip
Summary:        Sip files for %{name}
Group:          Development/Libraries/Python
Supplements:    packageand(python-sip:python-%{mname}) 
Provides:       %{oldpython}-%{mname}-sip = %{version}-%{release}
Obsoletes:      %{oldpython}-%{mname}-sip < %{version}-%{release}
Requires:       python-qt5-devel

%description sip
This package provides the SIP files used to generate the Python bindings for
%{name}

%package doc
Summary:        Examples for %{name}
Group:          Documentation/Other
Provides:       %{python_module %{mname}-examples = %{version}-%{release}}
BuildArch:      noarch

%description doc
This package provides %{name} examples.

%prep
%setup -q -n PyQtChart-%{version}

%build
%pyqt_build

%install
%pyqt_install
%pyqt_install_examples %mname

%files %{python_files}
%license LICENSE
%doc NEWS README
%dir %{python_sitearch}/PyQt5/
%{python_sitearch}/PyQt5/QtChart.*
%{python_sitearch}/[Pp]y[Qq]t[Cc]hart-%{version}.dist-info

%files %{python_files api}
%license LICENSE
%dir %{_datadir}/qt5/qsci/api/python_%{python_bin_suffix}/
%{_datadir}/qt5/qsci/api/python_%{python_bin_suffix}/PyQtChart.api

%files %{python_files sip}
%license LICENSE
%{pyqt5_sipdir}/QtChart/

%files %{python_files doc}
%license LICENSE
%{_docdir}/%{python_prefix}-%{mname}
%exclude %{_docdir}/%{python_prefix}-%{mname}/NEWS
%exclude %{_docdir}/%{python_prefix}-%{mname}/README

%changelog
* Mon Jun  9 2025 Ben Greiner <code@bnavigator.de>
- Allow lowercase distinfo due to new pyqt-builder following PEP 639
* Fri Nov  8 2024 Ben Greiner <code@bnavigator.de>
- Fix requires_eq replacement gh#openSUSE/python-rpm-macros#185
* Tue Nov  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Avoid using requires_eq, which after the last modifications
  conflicts with python singlespec (order of expansion).
* Thu Jan 25 2024 Ben Greiner <code@bnavigator.de>
- Enable SLE15 python module for more modern python in 15.x
* Tue Jun 21 2022 Ben Greiner <code@bnavigator.de>
- Update to version 5.15.6
  * Added the missing QXYSeries.points().
- Release 5.15.5
  * Added support for Python v3.10.
* Fri Jun 18 2021 Ben Greiner <code@bnavigator.de>
- Provide the PyPI name, without the s at the end
* Thu Mar 11 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.15.4
  * Packaging bug fixes.
- Fixes problems with packages checking the package metadata like
  boo#1183144
* Fri Feb 26 2021 Ben Greiner <code@bnavigator.de>
- Update to 5.15.3
  * Sync release with PyQt5
- Switch all distros to SIP v5+
- Disable Python 2 build
* Tue Nov 24 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 5.15.2
  * Build system changes
* Mon Sep 14 2020 Benjamin Greiner <code@bnavigator.de>
- Use sip5 where possible
* Mon Sep 14 2020 Benjamin Greiner <code@bnavigator.de>
- Update to Version 5.15.1
  * A bug-fix release.
- remove the superfluous Tumbleweed python2 skip hack
* Thu Aug 27 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 5.15.0
  * Added support for Qt Charts v5.15.0.
- v5.14.0 added support for Qt Charts v5.14.0 in December 2019
- The source location has changed to PyPI
* Fri Mar 13 2020 Christophe Giboudeaux <christophe@krop.fr>
- Stop building the python2 package for openSUSE Tumbleweed.
* Wed Nov 13 2019 Todd R <toddrme2178@gmail.com>
- Update to 5.13.1
  * Added support for SIP v5.
* Fri Jul 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.13.0
  Update bindings for QtCharts 5.13.0
* Wed Feb 27 2019 Todd R <toddrme2178@gmail.com>
- Make eric api files supplement eric.
- Make sip api files supplement sip.
- Fix sip api dependency.
* Thu Feb 21 2019 Todd R <toddrme2178@gmail.com>
- Update to 5.12
  * Fixed the QValueAxis.tickTypeChanged() signal.
  * Updated for Qt v5.12.
- Build both python2 and python3 flavors in a single spec file.
* Mon Oct 22 2018 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.11.3. Changes since 5.10.1:
  * Update the PyQt5 wheel to use.
  * Fixed all signal signatures.
- Run spec-cleaner
* Tue Apr 17 2018 termim@gmail.com
- Update to 5.10.1
  * Added support for Qt Charts v5.10.1.
* Fri Jan 26 2018 aloisio@gmx.com
- Update to 5.10
* Wed Feb 15 2017 termim@gmail.com
- Update to 5.8
* Tue Jan  3 2017 termim@gmail.com
- Update to 5.7.1
* Fri Jul 29 2016 termim@gmail.com
- initial checkin rev. 2.0.1
